Index: webrtc/base/socket.h |
diff --git a/webrtc/base/socket.h b/webrtc/base/socket.h |
index 5512c5de0a572b0572c441ff41c8101bb14b1b0f..8d98d273df6228d734d57fad9754ad0d17d4acfc 100644 |
--- a/webrtc/base/socket.h |
+++ b/webrtc/base/socket.h |
@@ -158,10 +158,10 @@ class Socket { |
}; |
virtual ConnState GetState() const = 0; |
// Fills in the given uint16 with the current estimate of the MTU along the |
// path to the address to which this socket is connected. NOTE: This method |
// can block for up to 10 seconds on Windows. |
- virtual int EstimateMTU(uint16* mtu) = 0; |
+ virtual int EstimateMTU(uint16_t* mtu) = 0; |
enum Option { |
OPT_DONTFRAGMENT, |
@@ -158,10 +158,10 @@ class Socket { |
}; |
virtual ConnState GetState() const = 0; |
- // Fills in the given uint16 with the current estimate of the MTU along the |
+ // Fills in the given uint16_t with the current estimate of the MTU along the |
// path to the address to which this socket is connected. NOTE: This method |
// can block for up to 10 seconds on Windows. |